require "import"
import "android.content.Intent"
import "android.content.pm.ApplicationInfo"
import "android.content.Context"
import "android.content.pm.PackageManager"
import "android.widget.ArrayAdapter"
import "android.widget.GridView"
import "android.widget.LinearLayout"
import "android.widget.TextView"
import "android.widget.Toast"
import "android.os.Vibrator"
import "android.view.Gravity"
import "com.androlua.*"
local context = activity or service
local packageManager = context.getPackageManager()
local vibrator = context.getSystemService(Context.VIBRATOR_SERVICE)

local selectedApp1, selectedApp2 = nil, nil

-- Función para abrir las aplicaciones en pantalla dividida
local function openAppsInSplitScreen()
    if selectedApp1 then
        local intent1 = packageManager.getLaunchIntentForPackage(selectedApp1.packageName)

        if intent1 then
            intent1.addFlags(Intent.FLAG_ACTIVITY_LAUNCH_ADJACENT)

            context.startActivity(intent1)
        else
            Toast.makeText(context, "No se encontró el intent de lanzamiento para la aplicación seleccionada", Toast.LENGTH_SHORT).show()
        end
    else
        Toast.makeText(context, "Debes seleccionar una aplicación", Toast.LENGTH_SHORT).show()
    end
end

-- Obtener la lista de aplicaciones instaladas
local installedApplications = packageManager.getInstalledApplications(PackageManager.GET_META_DATA)

-- Crear una lista de nombres de aplicaciones y un diccionario de aplicaciones con nombres correspondientes
local appNames = {}
local installedAppInfos = {}
for i = 1, installedApplications.size() do
    local appInfo = installedApplications.get(i - 1)
    if (appInfo.flags & ApplicationInfo.FLAG_SYSTEM) == 0 then
        local appName = appInfo.loadLabel(packageManager)
        local packageName = appInfo.packageName
        local intent = packageManager.getLaunchIntentForPackage(packageName)
        if intent then
            installedAppInfos[appName] = appInfo
            appNames[#appNames + 1] = appName
        end
    end
end

-- Ordenar la lista de nombres de aplicaciones en orden alfabético
table.sort(appNames)

-- Crear una vista de cuadrícula utilizando AndroLua
local gridView = GridView(context)
gridView.setNumColumns(1)
gridView.setLayoutParams(LinearLayout.LayoutParams(LinearLayout.LayoutParams.MATCH_PARENT, LinearLayout.LayoutParams.MATCH_PARENT))
local adapter = ArrayAdapter(context, android.R.layout.simple_list_item_1, appNames)
gridView.setAdapter(adapter)

-- Crear un layout lineal vertical y agregar el título y la vista de cuadrícula
local linearLayout = LinearLayout(context)
linearLayout.setOrientation(LinearLayout.VERTICAL)
linearLayout.setLayoutParams(LinearLayout.LayoutParams(LinearLayout.LayoutParams.MATCH_PARENT, LinearLayout.LayoutParams.MATCH_PARENT))

local titleTextView = TextView(context)
titleTextView.setText("Pilih aplikasi")
titleTextView.setTextSize(20)
titleTextView.setGravity(Gravity.CENTER)
titleTextView.setPadding(16, 16, 16, 16)

linearLayout.addView(titleTextView)
linearLayout.addView(gridView)

-- Crear el diálogo utilizando LuaDialog y establecer el contenido como el layout lineal
local dlg = LuaDialog(context)
dlg.setTitle("Pilih aplikasi")
dlg.setView(linearLayout)

-- Manejar el evento de clic en la cuadrícula
gridView.setOnItemClickListener{
    onItemClick = function(parent, view, position, id)
        local appName = appNames[position + 1]
        vibrator.vibrate(100)
        Toast.makeText(context, " " .. appName, Toast.LENGTH_SHORT).show()

        if not selectedApp1 then
            selectedApp1 = installedAppInfos[appName]
            openAppsInSplitScreen()
            dlg.dismiss()
        end
    end
}

dlg.show()